@@ -1,12 +1,7 @@
-# encoding: utf-8
-
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import unicode_literals
-
 import itertools
 from collections import OrderedDict
 
@@ -19,7 +14,7 @@ nan = float("nan")
 inf = float("inf")
 
 
-class Test_Dictionary_is_type(object):
+class Test_Dictionary_is_type:
     @pytest.mark.parametrize(
         ["value", "strict_level", "expected"],
         [
@@ -35,9 +30,12 @@ class Test_Dictionary_is_type(object):
                 [True],
             )
         )
+        + [['{"foo": 10}', StrictLevel.MIN, True], ['{"foo": 10}', StrictLevel.MAX, False],]
         + list(
             itertools.product(
-                [1, "a", nan, True, None], [StrictLevel.MIN, StrictLevel.MAX], [False]
+                [1, "a", "あ".encode("utf8"), nan, True, None],
+                [StrictLevel.MIN, StrictLevel.MAX],
+                [False],
             )
         ),
     )
