@@ -1,15 +1,9 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, unicode_literals
-
 import decimal
 
-import six
-
 from .._common import strip_ansi_escape
 from .._const import DefaultValue, ParamKey
 from ..error import TypeConversionError
@@ -18,16 +12,18 @@ from ._interface import AbstractValueConverter
 
 class FloatConverter(AbstractValueConverter):
     def __init__(self, value, params):
-        super(FloatConverter, self).__init__(value, params)
+        super().__init__(value, params)
 
-        self.float_class = DefaultValue.FLOAT_TYPE
+        self.float_class = self._params.get("float_type")
+        if self.float_class is None:
+            self.float_class = DefaultValue.FLOAT_TYPE
 
     def force_convert(self):
         if isinstance(self._value, self.float_class):
             return self._value
 
         if isinstance(self._value, float):
-            return self.float_class(six.text_type(self._value))
+            return self.float_class(str(self._value))
 
         try:
             return self.float_class(self._value)
